pub struct SimpleActivity {
pub id: Url,
pub kind: String,
pub to: Vec<Url>,
pub cc: Vec<Url>,
pub actor: Either<Url, SimpleActor>,
pub object: Either<Url, Either<Box<SimpleActivity>, SimpleObject>>,
pub rest: Map<String, Value>,
}Fields
id: Urlkind: Stringto: Vec<Url>cc: Vec<Url>actor: Either<Url, SimpleActor>object: Either<Url, Either<Box<SimpleActivity>, SimpleObject>>rest: Map<String, Value>Trait Implementations
Sourceimpl Activity for SimpleActivity
impl Activity for SimpleActivity
Sourceimpl ActivityExt for SimpleActivity
impl ActivityExt for SimpleActivity
Sourcetype ObjectId = ActivityOrObjectId
type ObjectId = ActivityOrObjectId
The Object ID type for dereferencing an Object
Sourcefn dereference_actor<'life0, 'async_trait, I, R, S>(
&'life0 self,
actor_id: <I as Ingest<<Self::ActorId as Dereference>::Output>>::ActorId,
ingest: I,
remote_repo: R,
session: S,
) -> Pin<Box<dyn Future<Output = Result<Option<<Self::ActorId as Dereference>::Output>, <I as Ingest<<Self::ActorId as Dereference>::Output>>::Error>> + 'async_trait>>where
'life0: 'async_trait,
<I as Ingest<<Self::ActorId as Dereference>::Output>>::Error: From<<R as Repo>::Error>,
<I as Ingest<<Self::ActorId as Dereference>::Output>>::ActorId: From<Url> + 'static,
I: 'async_trait + Ingest<<Self::ActorId as Dereference>::Output>,
R: 'async_trait + Repo,
S: 'async_trait + Session,
Self: 'async_trait,
fn dereference_actor<'life0, 'async_trait, I, R, S>(
&'life0 self,
actor_id: <I as Ingest<<Self::ActorId as Dereference>::Output>>::ActorId,
ingest: I,
remote_repo: R,
session: S,
) -> Pin<Box<dyn Future<Output = Result<Option<<Self::ActorId as Dereference>::Output>, <I as Ingest<<Self::ActorId as Dereference>::Output>>::Error>> + 'async_trait>>where
'life0: 'async_trait,
<I as Ingest<<Self::ActorId as Dereference>::Output>>::Error: From<<R as Repo>::Error>,
<I as Ingest<<Self::ActorId as Dereference>::Output>>::ActorId: From<Url> + 'static,
I: 'async_trait + Ingest<<Self::ActorId as Dereference>::Output>,
R: 'async_trait + Repo,
S: 'async_trait + Session,
Self: 'async_trait,
Pull the actor off the activity, or fetch it from a repo if it isn’t present
Sourcefn dereference_object<'life0, 'async_trait, I, R, S>(
&'life0 self,
actor_id: <I as Ingest<<Self::ObjectId as Dereference>::Output>>::ActorId,
ingest: I,
remote_repo: R,
session: S,
) -> Pin<Box<dyn Future<Output = Result<Option<<Self::ObjectId as Dereference>::Output>, <I as Ingest<<Self::ObjectId as Dereference>::Output>>::Error>> + 'async_trait>>where
'life0: 'async_trait,
<I as Ingest<<Self::ObjectId as Dereference>::Output>>::Error: From<<R as Repo>::Error>,
<I as Ingest<<Self::ObjectId as Dereference>::Output>>::ActorId: From<Url> + 'static,
I: 'async_trait + Ingest<<Self::ObjectId as Dereference>::Output>,
R: 'async_trait + Repo,
S: 'async_trait + Session,
Self: 'async_trait,
fn dereference_object<'life0, 'async_trait, I, R, S>(
&'life0 self,
actor_id: <I as Ingest<<Self::ObjectId as Dereference>::Output>>::ActorId,
ingest: I,
remote_repo: R,
session: S,
) -> Pin<Box<dyn Future<Output = Result<Option<<Self::ObjectId as Dereference>::Output>, <I as Ingest<<Self::ObjectId as Dereference>::Output>>::Error>> + 'async_trait>>where
'life0: 'async_trait,
<I as Ingest<<Self::ObjectId as Dereference>::Output>>::Error: From<<R as Repo>::Error>,
<I as Ingest<<Self::ObjectId as Dereference>::Output>>::ActorId: From<Url> + 'static,
I: 'async_trait + Ingest<<Self::ObjectId as Dereference>::Output>,
R: 'async_trait + Repo,
S: 'async_trait + Session,
Self: 'async_trait,
Pull the object off the activity, or fetch it from a repo if it isn’t present
Sourceimpl Clone for SimpleActivity
impl Clone for SimpleActivity
Sourcefn clone(&self) -> SimpleActivity
fn clone(&self) -> SimpleActivity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimpleActivity
impl Debug for SimpleActivity
Sourceimpl DeliverableObject for SimpleActivity
impl DeliverableObject for SimpleActivity
Sourcefn has_named_recipient(&self, actor_id: &Url) -> bool
fn has_named_recipient(&self, actor_id: &Url) -> bool
Determine if a given actor is in the list of recipients for this object
Sourceimpl<'de> Deserialize<'de> for SimpleActivity
impl<'de> Deserialize<'de> for SimpleActivity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Object for SimpleActivity
impl Object for SimpleActivity