pub struct SimpleActor {
pub id: Url,
pub kind: String,
pub inbox: Url,
pub outbox: Url,
pub preferred_username: String,
pub public_key: SimplePublicKey,
pub name: Option<String>,
pub endpoints: Option<SimpleEndpoints>,
pub rest: Map<String, Value>,
}Fields
id: Urlkind: Stringinbox: Urloutbox: Urlpreferred_username: Stringpublic_key: SimplePublicKeyname: Option<String>endpoints: Option<SimpleEndpoints>rest: Map<String, Value>Trait Implementations
Sourceimpl Actor for SimpleActor
impl Actor for SimpleActor
Sourcefn preferred_username(&self) -> &str
fn preferred_username(&self) -> &str
The actor’s preferred username (handle)
Sourcefn public_key_id(&self) -> &Url
fn public_key_id(&self) -> &Url
The actor’s public key ID
The actor’s shared inbox
Sourcefn canonical_name(&self) -> &str
fn canonical_name(&self) -> &str
Determine the name of an actor
Sourcefn delivery_inbox<O>(&self, obj: &O) -> &Urlwhere
O: DeliverableObject,
fn delivery_inbox<O>(&self, obj: &O) -> &Urlwhere
O: DeliverableObject,
Determine which inbox an object should be delievered to
Sourceimpl ActorExt for SimpleActor
impl ActorExt for SimpleActor
Sourcetype PublicKeyId = PublicKeyId
type PublicKeyId = PublicKeyId
The Public Key ID for dereferencing a Public key
Sourcefn public_key(&self) -> Option<Out<Self::PublicKeyId>>
fn public_key(&self) -> Option<Out<Self::PublicKeyId>>
Attempt to pull the public key off the actor
Sourcefn dereference_public_key<'life0, 'async_trait, I, R, S>(
&'life0 self,
actor_id: <I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::ActorId,
ingest: I,
remote_repo: R,
session: S,
) -> Pin<Box<dyn Future<Output = Result<Option<<Self::PublicKeyId as Dereference>::Output>, <I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::Error>> + 'async_trait>>where
'life0: 'async_trait,
<I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::Error: From<<R as Repo>::Error>,
<I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::ActorId: From<Url> + 'static,
I: 'async_trait + Ingest<<Self::PublicKeyId as Dereference>::Output>,
R: 'async_trait + Repo,
S: 'async_trait + Session,
Self: 'async_trait,
fn dereference_public_key<'life0, 'async_trait, I, R, S>(
&'life0 self,
actor_id: <I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::ActorId,
ingest: I,
remote_repo: R,
session: S,
) -> Pin<Box<dyn Future<Output = Result<Option<<Self::PublicKeyId as Dereference>::Output>, <I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::Error>> + 'async_trait>>where
'life0: 'async_trait,
<I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::Error: From<<R as Repo>::Error>,
<I as Ingest<<Self::PublicKeyId as Dereference>::Output>>::ActorId: From<Url> + 'static,
I: 'async_trait + Ingest<<Self::PublicKeyId as Dereference>::Output>,
R: 'async_trait + Repo,
S: 'async_trait + Session,
Self: 'async_trait,
Pull the public key off the acctor, or fetch it from a repo if it isn’t present
Sourceimpl Clone for SimpleActor
impl Clone for SimpleActor
Sourcefn clone(&self) -> SimpleActor
fn clone(&self) -> SimpleActor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimpleActor
impl Debug for SimpleActor
Sourceimpl<'de> Deserialize<'de> for SimpleActor
impl<'de> Deserialize<'de> for SimpleActor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Object for SimpleActor
impl Object for SimpleActor